Page 125 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 125

Home

    Starting from the early days of the Soviet Regime, it
    couldn't possibly have survived without Western, and
    especially American help. All experts who came from
    Soviet Russia from the early 20s have been saying, ‘don't
    help our oppressors!"

    The destruction of religion made possible in the
    Soviet Union by help from the United States has also
    been repeated in the Soviet's satellite nations in Eastern
    Europe. A knowledgeable authority on this subject is
    former United States Ambassador to Romania, David
    Funderburk, who spent six years living in Eastern
    Europe. Here are some of his first hand observations:

    In Romania, when I served as United States
    Ambassador, also subsequent to that, I was able to
    observe and witness through intelligence information,
    and otherwise, the steady, weekly destruction of
    churches, Pentecostal, Baptist, Brethren, Lutheran,
    Calvinist, Catholic, and Orthodox; the jailing of anybody
    who spoke out religiously, or who took part actively in a
    religious practice, and the murder of some Baptist and
    Pentecostal pastors and Catholic priests. All of this was
    taking place under Ceausescu, who at the time was given
    most favored nation treaty status by the United States. In
    other words, he was considered a favorite of Washington
    and the State Department, while at the same time he was
    carrying out a massive destruction of churches and
    religious believers.

    120

    The Secret Side of History

    Mr. Alburt also had this to say about those who have

    kept the Communists in power: